/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_endian.h,v 1.5 1998/10/06 18:26:03 slouken Exp $";
#endif

/* Functions for dynamically reading and writing endian-specific values */

#ifndef _SDL_endian_h
#define _SDL_endian_h

/* These functions read and write data of the specified endianness, dynamically
   calculating and translating to the host machine endianness.

   e.g.: If you want to read a 16 bit value on big-endian machine from
         an open file containing little endian values, you would use:

		value = ReadLE16(fp);
*/

#include <stdio.h>

#include "SDL_types.h"

#include "begin_code.h"

/* This is called by SDL_Init(), returns 1234/4321 for little/big endianness */
#define SDL_LIL_ENDIAN	1234
#define SDL_BIG_ENDIAN	4321
SDL_DEFUN(int, SDL_CalculateEndian, (void))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_CalculateEndian _SDL_CalculateEndian
#endif
/**/

/* Byteswap item from the specified endianness to the native endianness */
SDL_DEFUN(Uint16, SDL_SwapLE16, (Uint16 item))
SDL_DEFUN(Uint16, SDL_SwapBE16, (Uint16 item))
SDL_DEFUN(Uint32, SDL_SwapLE32, (Uint32 item))
SDL_DEFUN(Uint32, SDL_SwapBE32, (Uint32 item))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_SwapLE16 _SDL_SwapLE16
# define SDL_SwapBE16 _SDL_SwapBE16
# define SDL_SwapLE32 _SDL_SwapLE32
# define SDL_SwapBE32 _SDL_SwapBE32
#endif
/**/

/* Read an item of the specified endianness and return in native format */
SDL_DEFUN(Uint16, SDL_ReadLE16, (FILE *fp))
SDL_DEFUN(Uint16, SDL_ReadBE16, (FILE *fp))
SDL_DEFUN(Uint32, SDL_ReadLE32, (FILE *fp))
SDL_DEFUN(Uint32, SDL_ReadBE32, (FILE *fp))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_ReadLE16 _SDL_ReadLE16
# define SDL_ReadBE16 _SDL_ReadBE16
# define SDL_ReadLE32 _SDL_ReadLE32
# define SDL_ReadBE32 _SDL_ReadBE32
#endif
/**/

/* Write an item of native format to the specified endianness */
SDL_DEFUN(int, SDL_WriteLE16, (FILE *fp, Uint16 value))
SDL_DEFUN(int, SDL_WriteBE16, (FILE *fp, Uint16 value))
SDL_DEFUN(int, SDL_WriteLE32, (FILE *fp, Uint32 value))
SDL_DEFUN(int, SDL_WriteBE32, (FILE *fp, Uint32 value))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_WriteLE16 _SDL_WriteLE16
# define SDL_WriteBE16 _SDL_WriteBE16
# define SDL_WriteLE32 _SDL_WriteLE32
# define SDL_WriteBE32 _SDL_WriteBE32
#endif
/**/

#include "close_code.h"

#endif /* _SDL_endian_h */
