/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_keyboard.h,v 1.5 1998/10/06 18:07:24 slouken Exp $";
#endif

/* Include file for SDL keyboard event handling */

#ifndef _SDL_keyboard_h
#define _SDL_keyboard_h

#include "SDL_types.h"
#include "SDL_keysym.h"

#include "begin_code.h"

/* Keysym structure */
typedef struct {
	SDLKey sym;			/* The SDL keysym */
	SDLMod mod;			/* Any key modifications */
} SDL_keysym;

/* Function prototypes */
/*
 * Get a snapshot of the current state of the keyboard.
 * Returns an array of keystates, indexed by the SDLK_* syms.
 * Used:
 * 	Uint8 *keystate = SDL_GetKeyState(NULL);
 *	if ( keystate[SDLK_RETURN] ) ... <RETURN> is pressed.
 */
SDL_DEFUN(Uint8 *, SDL_GetKeyState, (int *numkeys))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_GetKeyState _SDL_GetKeyState
#endif
/**/

/*
 * Get the current key modifier state
 */
SDL_DEFUN(SDLMod, SDL_GetModState, (void))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_GetModState _SDL_GetModState
#endif
/**/

/* 
 * Converts a keysym to it's ascii representation, if it has one.
 * If the keysym doesn't have an ascii representation, returns 0.
 * If symname is not null, it is assigned the name of the keysym.
 */
SDL_DEFUN(Uint8, SDL_SymToASCII, (SDL_keysym *keysym, char **symname))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_SymToASCII _SDL_SymToASCII
#endif
/**/

#include "close_code.h"

#endif /* _SDL_keyboard_h */
