/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_keysym.h,v 1.1.1.1 1998/07/14 01:51:17 slouken Exp $";
#endif

#ifndef _SDL_keysym_h
#define _SDL_keysym_h

/* What we really want is a mapping of every raw key on the keyboard */
 
/* Enumeration of valid syms -- 0-127 map to the ASCII character set */
typedef enum {
	SDLK_BACKSPACE = 8,
	SDLK_TAB = 9,
	SDLK_CLEAR = 12,
	SDLK_RETURN = 13,
	SDLK_ESCAPE = 27,
	SDLK_SPACE = 32,
	SDLK_QUOTE = 39,
	SDLK_COMMA = 44,
	SDLK_MINUS = 45,
	SDLK_PERIOD = 46,
	SDLK_SLASH = 47,
	SDLK_0 = 48,
	SDLK_1 = 49,
	SDLK_2 = 50,
	SDLK_3 = 51,
	SDLK_4 = 52,
	SDLK_5 = 53,
	SDLK_6 = 54,
	SDLK_7 = 55,
	SDLK_8 = 56,
	SDLK_9 = 57,
	SDLK_SEMICOLON = 59,
	SDLK_EQUALS = 61,
	SDLK_KP0 = 70,
	SDLK_KP1 = 71,
	SDLK_KP2 = 72,
	SDLK_KP3 = 73,
	SDLK_KP4 = 74,
	SDLK_KP5 = 75,
	SDLK_KP6 = 76,
	SDLK_KP7 = 77,
	SDLK_KP8 = 78,
	SDLK_KP9 = 79,
	SDLK_KP_PERIOD = 80,
	SDLK_KP_DIVIDE = 81,
	SDLK_KP_MULTIPLY = 82,
	SDLK_KP_MINUS = 83,
	SDLK_KP_PLUS = 84,
	SDLK_KP_ENTER = 85,
	SDLK_KP_EQUALS = 86,
	SDLK_LEFTBRACKET = 91,
	SDLK_BACKSLASH = 92,
	SDLK_RIGHTBRACKET = 93,
	SDLK_BACKQUOTE = 96,
	SDLK_a = 97,
	SDLK_b = 98,
	SDLK_c = 99,
	SDLK_d = 100,
	SDLK_e = 101,
	SDLK_f = 102,
	SDLK_g = 103,
	SDLK_h = 104,
	SDLK_i = 105,
	SDLK_j = 106,
	SDLK_k = 107,
	SDLK_l = 108,
	SDLK_m = 109,
	SDLK_n = 110,
	SDLK_o = 111,
	SDLK_p = 112,
	SDLK_q = 113,
	SDLK_r = 114,
	SDLK_s = 115,
	SDLK_t = 116,
	SDLK_u = 117,
	SDLK_v = 118,
	SDLK_w = 119,
	SDLK_x = 120,
	SDLK_y = 121,
	SDLK_z = 122,
	SDLK_DELETE = 127,
	SDLK_F1 = 128,
	SDLK_F2 = 129,
	SDLK_F3 = 130,
	SDLK_F4 = 131,
	SDLK_F5 = 132,
	SDLK_F6 = 133,
	SDLK_F7 = 134,
	SDLK_F8 = 135,
	SDLK_F9 = 136,
	SDLK_F10 = 137,
	SDLK_F11 = 138,
	SDLK_F12 = 139,
	SDLK_F13 = 140,
	SDLK_F14 = 141,
	SDLK_F15 = 142,
	SDLK_PAUSE = 143,
	SDLK_NUMLOCK = 144,
	SDLK_UP = 145,
	SDLK_DOWN = 146,
	SDLK_RIGHT = 147,
	SDLK_LEFT = 148,
	SDLK_INSERT = 149,
	SDLK_HOME = 150,
	SDLK_END = 151,
	SDLK_PAGEUP = 152,
	SDLK_PAGEDOWN = 153,
	SDLK_CAPSLOCK = 154,
	SDLK_SCROLLOCK = 155,
	SDLK_RSHIFT = 156,
	SDLK_LSHIFT = 157,
	SDLK_RCTRL = 158,
	SDLK_LCTRL = 159,
	SDLK_RALT = 160,
	SDLK_LALT = 161,
	SDLK_RMETA = 162,
	SDLK_LMETA = 163,
	SDLK_HELP = 164,
	SDLK_PRINT = 165,
	SDLK_SYSREQ = 166,
	SDLK_MENU = 167,
	SDLK_BREAK = 168,
	SDLK_EURO = 169,		/* Some european keyboards */
	SDLK_POWER = 170,		/* Power Macintosh power key */
	/* Add any other keys (to a maximum of 255) here */
	SDLK_NONE
} SDLKey;

/* Enumeration of valid key mods (possibly OR'd together) */
typedef enum {
	KMOD_NONE  = 0x00,
	KMOD_NUM   = 0x01,
	KMOD_LCTRL = 0x02,
	KMOD_RCTRL = 0x04,
	KMOD_CAPS  = 0x10,
	KMOD_RSHIFT= 0x20,
	KMOD_LSHIFT= 0x40,
	KMOD_LALT  = 0x80,
	KMOD_RALT  = 0x08
} SDLMod;

#define KMOD_CTRL	(KMOD_LCTRL|KMOD_RCTRL)
#define KMOD_SHIFT	(KMOD_LSHIFT|KMOD_RSHIFT)
#define KMOD_ALT	(KMOD_LALT|KMOD_RALT)

#endif /* _SDL_keysym_h */
