/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_syswm.h,v 1.8 1998/10/15 07:56:08 slouken Exp $";
#endif

/* Include file for SDL custom system window manager hooks */

#ifndef _SDL_syswm_h
#define _SDL_syswm_h

#include "SDL_version.h"

#include "begin_code.h"

/* Your application has access to a special type of event 'SDL_SYSWMEVENT',
   which contains window-manager specific information and arrives whenever
   an unhandled window event occurs.  This event is ignored by default, but
   you can enable it with SDL_EventState()
*/

/* This is the structure for custom window manager events */
/* X11 specific -- fix me? */
#if defined(__unix__) || defined(unix)
#include <X11/Xlib.h>
#include <X11/Xatom.h>

/* The X11 custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	XEvent xevent;
};

/* The windows custom window manager information structure */
typedef struct {
	SDL_version version;
	Display *display;		/* The X11 display */
	Window window;			/* The X11 display window */
} SDL_SysWMinfo;

#elif defined __WIN32__
#include <windows.h>

/* The windows custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	HWND hwnd;			/* The window for the message */
	UINT msg;			/* The type of message */
	WPARAM wParam;			/* WORD message parameter */
	LPARAM lParam;			/* LONG message parameter */
};

/* The windows custom window manager information structure */
typedef struct {
	SDL_version version;
	HWND window;			/* The Win32 display window */
} SDL_SysWMinfo;

#else

/* The generic custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/* The generic custom window manager information structure */
typedef struct {
	SDL_version version;
	int data;
} SDL_SysWMinfo;

#endif

/* Function prototypes */
/*
 * This function gives you custom hooks into the window manager information.
 * It fills the structure pointed to by 'info' with custom information and
 * returns 1 if the function is implemented.  If it's not implemented, it
 * returns 0. 
 * If the version member of the 'info' structure isn't valid, this function
 * returns -1.
 */
SDL_DEFUN(int, SDL_GetWMInfo, (SDL_SysWMinfo *info))
/**/
#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
# define SDL_GetWMInfo _SDL_GetWMInfo
#endif
/**/

#include "close_code.h"

#endif /* _SDL_syswm_h */
